complete -c dummyhttp -s p -l port -d 'Port on which to listen' -r
complete -c dummyhttp -s H -l headers -d 'Headers to send (format: key:value)' -r
complete -c dummyhttp -s c -l code -d 'HTTP status code to send' -r
complete -c dummyhttp -s b -l body -d 'HTTP body to send' -r
complete -c dummyhttp -s i -l interface -d 'Interface to bind to' -r
complete -c dummyhttp -l print-completions -d 'Generate completion file for a shell' -r -f -a "{bash	,elvish	,fish	,powershell	,zsh	}"
complete -c dummyhttp -l tls-cert -d 'TLS certificate to use' -r -F
complete -c dummyhttp -l tls-key -d 'TLS private key to use' -r -F
complete -c dummyhttp -s q -l quiet -d 'Be quiet (log nothing)'
complete -c dummyhttp -s v -l verbose -d 'Be verbose (log data of incoming and outgoing requests). If given twice it will also log the body data'
complete -c dummyhttp -l print-manpage -d 'Generate man page'
complete -c dummyhttp -s h -l help -d 'Print help (see more with \'--help\')'
complete -c dummyhttp -s V -l version -d 'Print version'
